==> synthdef-json-decoder-0.5.0.tgz: package/lib/SynthDefDecoder1.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var SynthDefDecoder2 = require("./SynthDefDecoder2");

var SynthDefDecoder1 = function (_SynthDefDecoder) {
  _inherits(SynthDefDecoder1, _SynthDefDecoder);

  function SynthDefDecoder1() {
    _classCallCheck(this, SynthDefDecoder1);

    return _possibleConstructorReturn(this, Object.getPrototypeOf(SynthDefDecoder1).apply(this, arguments));
  }

  _createClass(SynthDefDecoder1, [{
    key: "readNumberOfConstants",
    value: function readNumberOfConstants() {
      return this.reader.readInt16();
    }
  }, {
    key: "readNumberOfParamValues",
    value: function readNumberOfParamValues() {
      return this.reader.readInt16();
    }
  }, {
    key: "readNumberOfParamIndices",
    value: function readNumberOfParamIndices() {
      return this.reader.readInt16();
    }
  }, {
    key: "readParamNameIndex",
    value: function readParamNameIndex() {
      return this.reader.readInt16();
    }
  }, {
    key: "readNumberOfUnits",
    value: function readNumberOfUnits() {
      return this.reader.readInt16();
    }
  }, {
    key: "readUGenNumberOfInputs",
    value: function readUGenNumberOfInputs() {
      return this.reader.readInt16();
    }
  }, {
    key: "readIndexOfUGen",
    value: function readIndexOfUGen() {
      return this.reader.readInt16();
    }
  }, {
    key: "readIndexOfUGenOutput",
    value: function readIndexOfUGenOutput() {
      return this.reader.readInt16();
    }
  }, {
    key: "readUGenNumberOfOutputs",
    value: function readUGenNumberOfOutputs() {
      return this.reader.readInt16();
    }
  }]);

  return SynthDefDecoder1;
}(SynthDefDecoder2);

module.exports = SynthDefDecoder1;

==> synthdef-json-decoder-1.0.1.tgz: package/lib/SynthDefDecoder1.js <==
"use strict";

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var SynthDefDecoder2 = require("./SynthDefDecoder2");

var SynthDefDecoder1 = function (_SynthDefDecoder) {
  _inherits(SynthDefDecoder1, _SynthDefDecoder);

  function SynthDefDecoder1() {
    _classCallCheck(this, SynthDefDecoder1);

    return _possibleConstructorReturn(this, (SynthDefDecoder1.__proto__ || Object.getPrototypeOf(SynthDefDecoder1)).apply(this, arguments));
  }

  _createClass(SynthDefDecoder1, [{
    key: "readNumberOfConstants",
    value: function readNumberOfConstants() {
      return this.reader.readInt16();
    }
  }, {
    key: "readNumberOfParamValues",
    value: function readNumberOfParamValues() {
      return this.reader.readInt16();
    }
  }, {
    key: "readNumberOfParamIndices",
    value: function readNumberOfParamIndices() {
      return this.reader.readInt16();
    }
  }, {
    key: "readParamNameIndex",
    value: function readParamNameIndex() {
      return this.reader.readInt16();
    }
  }, {
    key: "readNumberOfUnits",
    value: function readNumberOfUnits() {
      return this.reader.readInt16();
    }
  }, {
    key: "readUGenNumberOfInputs",
    value: function readUGenNumberOfInputs() {
      return this.reader.readInt16();
    }
  }, {
    key: "readIndexOfUGen",
    value: function readIndexOfUGen() {
      return this.reader.readInt16();
    }
  }, {
    key: "readIndexOfUGenOutput",
    value: function readIndexOfUGenOutput() {
      return this.reader.readInt16();
    }
  }, {
    key: "readUGenNumberOfOutputs",
    value: function readUGenNumberOfOutputs() {
      return this.reader.readInt16();
    }
  }]);

  return SynthDefDecoder1;
}(SynthDefDecoder2);

module.exports = SynthDefDecoder1;
